@@ -20,7 +20,7 @@ def calc_contrast_loss(features,assignment_orig,device):
         top_elem = (feats.topk(n_neighb,1)[1]).reshape(100*nbatch)        
         positives = torch.exp((torch.matmul(assignment_orig[top_elem],assignment_orig[top_elem].T)/temp))
         loss += -torch.log(positives).mean()*temp
-        print((assignment_orig[top_elem].argmax(1)==ph).sum()/top_elem.shape[0])
+        # print((assignment_orig[top_elem].argmax(1)==ph).sum()/top_elem.shape[0])
 
     return loss/assignment_orig.shape[1]
 
