@@ -15,8 +15,8 @@ def parameters(path, debug):
         
         # Patch contrastive learning parameters
         args['PCL_CNN_Architecture']='resnet50' # or resnet18
-        args['PCL_N_Workers']=2 # Number of data loading workers 
-        args['PCL_Epochs']=80 # Number of total epoch to run
+        args['PCL_N_Workers']=1 # Number of data loading workers 
+        args['PCL_Epochs']=100 # Number of total epoch to run
         args['PCL_N_Crops_per_Image']=110 # Number of crops chosen per image
         args['PCL_Patch_Size']=30 # Size of patches in pixels
         args['PCL_Stride']=0 # Size of stride between consecutive patches
@@ -25,7 +25,7 @@ def parameters(path, debug):
         args['PCL_Batch_Size']= 4 # Number of images per iteration
         args['PCL_Weight_Decay']= 1e-4 # Weight Decay
         args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
-        args['PCL_Learning_Rate']= 0.003 # Learning Rate
+        args['PCL_Learning_Rate']= 0.0003 # Learning Rate
         args['PCL_Temperature']= 0.07 # Softmax temperature                
         args['PCL_eliminate_Black_Background'] = True
         args['PCL_eliminate_White_Background'] = False
@@ -41,11 +41,11 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 3 if debug=='Index' else hp.choice('epochs',[6,15,30,100]) if debug=='Object' else 100
+        args['epochs'] = 3 if debug=='Index' else hp.choice('epochs',[6,15,30,500]) if debug=='Object' else 500
         args['lr_decay_factor'] = 0.25# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 11000#max(int(args['epochs']/2),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
-        args['batch_size'] = 2 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 14, 24]) if debug=='Object' else 8
+        args['batch_size'] = 4 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 14, 24]) if debug=='Object' else 24
         args['lr'] = 0 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 1
 
         # General
@@ -67,9 +67,9 @@ def parameters(path, debug):
         args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
         
         # Losses
-        args['ContrastACC_Pheno'] = 1# if debug=='Index' else hp.choice("ContrastACC_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.01
-        args['ContrastACC_Neigh'] = 1# if debug=='Index' else hp.choice("ContrastACC_Neigh", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 1
-        args['ContrastACC_Area'] = 1#4 if debug=='Index' else hp.choice("ContrastACC_Area", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001
+        args['ContrastACC_Pheno'] = 10# if debug=='Index' else hp.choice("ContrastACC_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.01
+        args['ContrastACC_Neigh'] = 10# if debug=='Index' else hp.choice("ContrastACC_Neigh", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 1
+        args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("ContrastACC_Area", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001
         args['PatchEntropy_Pheno'] = 0#1 if debug=='Index' else hp.choice("PatchEntropy_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.1   
         args['PatchEntropy_Neigh'] = 0#1 if debug=='Index' else hp.choice("PatchEntropy_Neigh", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.1
         args['PatchEntropy_Area'] = 0#4 if debug=='Index' else hp.choice("PatchEntropy_Area", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001                                             
@@ -305,7 +305,7 @@ def parameters(path, debug):
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
         args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 24]) if debug=='Object' else 24
-        args['lr'] = 1 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.1
+        args['lr'] = 2 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.01
 
         # General
         args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
@@ -320,14 +320,14 @@ def parameters(path, debug):
         args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True
-        args['Area_Learning'] = True
+        args['Area_Learning'] = False
         args['dropoutRate'] = 0# 1 if debug=='Index' else hp.choice('dropoutRate', [0.1, 0.2, 0.3,0.4]) if debug=='Object' else 0.2        
         args['attntnThreshold'] = 0# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
         args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
                 
         # Losses
-        args['ContrastACC_Pheno'] = 10#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
-        args['ContrastACC_Neigh'] = 10#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Pheno'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
         args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
         args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
         args['PatchEntropy_Neigh'] = 0#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
@@ -335,6 +335,7 @@ def parameters(path, debug):
         
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = True
+        args['TSNE_Perc_Pat'] = 0.75 # Percentage of patients to use to generate the tsne. 
 
     elif 'Tumor_subtype' in path:            
         
